is_tty

Function is_tty 

pub fn is_tty() -> bool
Check if stdout is a TTY

This is used to automatically disable fancy output modes when output is being piped or redirected, or when running in CI environments.