pub struct MultiNodeStreamManager { /* private fields */ }Expand description
Manager for coordinating multiple node streams
This manager handles polling all node streams in a non-blocking manner and provides access to their current state and output.
Implementations
Sourceimpl MultiNodeStreamManager
impl MultiNodeStreamManager
Sourcepub fn add_stream(&mut self, node: Node, receiver: Receiver<CommandOutput>)
pub fn add_stream(&mut self, node: Node, receiver: Receiver<CommandOutput>)
Add a new node stream
Sourcepub fn poll_all(&mut self) -> bool
pub fn poll_all(&mut self) -> bool
Poll all streams for new output (non-blocking)
Returns true if any stream received new data
Sourcepub fn streams(&self) -> &[NodeStream]
pub fn streams(&self) -> &[NodeStream]
Get all streams
Sourcepub fn streams_mut(&mut self) -> &mut [NodeStream]
pub fn streams_mut(&mut self) -> &mut [NodeStream]
Get mutable access to all streams
Sourcepub fn all_complete(&self) -> bool
pub fn all_complete(&self) -> bool
Check if all streams are complete
Sourcepub fn completed_count(&self) -> usize
pub fn completed_count(&self) -> usize
Get count of successfully completed streams (not failed)
Sourcepub fn failed_count(&self) -> usize
pub fn failed_count(&self) -> usize
Get count of failed streams
Sourcepub fn total_count(&self) -> usize
pub fn total_count(&self) -> usize
Get total stream count