Module parser

Module parser 

Jump host parsing for OpenSSH ProxyJump format

Structs

JumpHost
A single jump host specification

Constants

ABSOLUTE_MAX_JUMP_HOSTS
Absolute maximum number of jump hosts, even if configured higher SECURITY: Hard limit to prevent DoS attacks regardless of configuration
DEFAULT_MAX_JUMP_HOSTS
Default maximum number of jump hosts allowed in a chain SECURITY: Prevents resource exhaustion and excessive connection chains

Functions

get_max_jump_hosts
Get the maximum number of jump hosts allowed
parse_jump_hosts
Parse jump host specifications from OpenSSH ProxyJump format
parse_jump_hosts_with_key
Parse jump hosts and set SSH key for all hosts in the chain