Module security

Module security 

Security utilities for validating and sanitizing user input

Functions

sanitize_error_message
Sanitize error messages to prevent information leakage
validate_hostname
Sanitize a hostname to prevent injection attacks
validate_local_path
Validate and sanitize a local file path to prevent path traversal attacks
validate_remote_path
Validate a remote path string to prevent injection attacks
validate_username
Validate a username to prevent injection attacks