Jump host parsing for OpenSSH ProxyJump format
Structs
- Jump
Host - A single jump host specification
Constants
- ABSOLUTE_
MAX_ JUMP_ HOSTS - Absolute maximum number of jump hosts, even if configured higher SECURITY: Hard limit to prevent DoS attacks regardless of configuration
- DEFAULT_
MAX_ JUMP_ HOSTS - Default maximum number of jump hosts allowed in a chain SECURITY: Prevents resource exhaustion and excessive connection chains
Functions
- get_
max_ jump_ hosts - Get the maximum number of jump hosts allowed
- parse_
jump_ hosts - Parse jump host specifications from OpenSSH ProxyJump format
- parse_
jump_ hosts_ with_ key - Parse jump hosts and set SSH key for all hosts in the chain