Connection pooling module for SSH connections.
NOTE: This is a placeholder implementation. The async-ssh2-tokio Client doesn’t support connection reuse or cloning, so actual pooling is not currently possible. This module provides the infrastructure for future connection pooling when the underlying library supports it.
The current implementation always creates new connections but provides the API surface for connection pooling to minimize future refactoring.
Structs
- Connection
Pool - Connection pool for SSH connections.