pub struct SshHostConfig {Show 80 fields
pub block_type: Option<ConfigBlock>,
pub host_patterns: Vec<String>,
pub hostname: Option<String>,
pub user: Option<String>,
pub port: Option<u16>,
pub identity_files: Vec<PathBuf>,
pub proxy_jump: Option<String>,
pub proxy_command: Option<String>,
pub proxy_use_fdpass: Option<bool>,
pub strict_host_key_checking: Option<String>,
pub user_known_hosts_file: Option<PathBuf>,
pub global_known_hosts_file: Option<PathBuf>,
pub forward_agent: Option<bool>,
pub forward_x11: Option<bool>,
pub server_alive_interval: Option<u32>,
pub server_alive_count_max: Option<u32>,
pub connect_timeout: Option<u32>,
pub connection_attempts: Option<u32>,
pub batch_mode: Option<bool>,
pub compression: Option<bool>,
pub tcp_keep_alive: Option<bool>,
pub preferred_authentications: Vec<String>,
pub pubkey_authentication: Option<bool>,
pub password_authentication: Option<bool>,
pub keyboard_interactive_authentication: Option<bool>,
pub gssapi_authentication: Option<bool>,
pub host_key_algorithms: Vec<String>,
pub kex_algorithms: Vec<String>,
pub ciphers: Vec<String>,
pub macs: Vec<String>,
pub send_env: Vec<String>,
pub set_env: HashMap<String, String>,
pub local_forward: Vec<String>,
pub remote_forward: Vec<String>,
pub dynamic_forward: Vec<String>,
pub request_tty: Option<String>,
pub escape_char: Option<String>,
pub log_level: Option<String>,
pub syslog_facility: Option<String>,
pub protocol: Vec<String>,
pub address_family: Option<String>,
pub bind_address: Option<String>,
pub clear_all_forwardings: Option<bool>,
pub control_master: Option<String>,
pub control_path: Option<String>,
pub control_persist: Option<String>,
pub certificate_files: Vec<PathBuf>,
pub ca_signature_algorithms: Vec<String>,
pub gateway_ports: Option<String>,
pub exit_on_forward_failure: Option<bool>,
pub permit_remote_open: Vec<String>,
pub hostbased_authentication: Option<bool>,
pub hostbased_accepted_algorithms: Vec<String>,
pub permit_local_command: Option<bool>,
pub local_command: Option<String>,
pub remote_command: Option<String>,
pub known_hosts_command: Option<String>,
pub fork_after_authentication: Option<bool>,
pub session_type: Option<String>,
pub stdin_null: Option<bool>,
pub no_host_authentication_for_localhost: Option<bool>,
pub hash_known_hosts: Option<bool>,
pub check_host_ip: Option<bool>,
pub visual_host_key: Option<bool>,
pub host_key_alias: Option<String>,
pub verify_host_key_dns: Option<String>,
pub update_host_keys: Option<String>,
pub number_of_password_prompts: Option<u32>,
pub enable_ssh_keysign: Option<bool>,
pub bind_interface: Option<String>,
pub ipqos: Option<String>,
pub rekey_limit: Option<String>,
pub forward_x11_timeout: Option<String>,
pub forward_x11_trusted: Option<bool>,
pub identities_only: Option<bool>,
pub add_keys_to_agent: Option<String>,
pub identity_agent: Option<String>,
pub pubkey_accepted_algorithms: Vec<String>,
pub required_rsa_size: Option<u32>,
pub fingerprint_hash: Option<String>,
}Expand description
SSH configuration for a specific host or match block
Fields
block_type: Option<ConfigBlock>Block type (Host patterns or Match conditions)
host_patterns: Vec<String>Host patterns (for backward compatibility and Host blocks)
hostname: Option<String>user: Option<String>port: Option<u16>identity_files: Vec<PathBuf>proxy_jump: Option<String>proxy_command: Option<String>proxy_use_fdpass: Option<bool>ProxyUseFdpass option - specifies whether ProxyCommand will pass a file descriptor Note: This option is parsed from SSH config but not yet used in the actual SSH client implementation as bssh doesn’t currently support proxy connections.
strict_host_key_checking: Option<String>user_known_hosts_file: Option<PathBuf>global_known_hosts_file: Option<PathBuf>forward_agent: Option<bool>forward_x11: Option<bool>server_alive_interval: Option<u32>server_alive_count_max: Option<u32>connect_timeout: Option<u32>connection_attempts: Option<u32>batch_mode: Option<bool>compression: Option<bool>tcp_keep_alive: Option<bool>preferred_authentications: Vec<String>pubkey_authentication: Option<bool>password_authentication: Option<bool>keyboard_interactive_authentication: Option<bool>gssapi_authentication: Option<bool>host_key_algorithms: Vec<String>kex_algorithms: Vec<String>ciphers: Vec<String>macs: Vec<String>send_env: Vec<String>set_env: HashMap<String, String>local_forward: Vec<String>remote_forward: Vec<String>dynamic_forward: Vec<String>request_tty: Option<String>escape_char: Option<String>log_level: Option<String>syslog_facility: Option<String>protocol: Vec<String>address_family: Option<String>bind_address: Option<String>clear_all_forwardings: Option<bool>control_master: Option<String>control_path: Option<String>control_persist: Option<String>certificate_files: Vec<PathBuf>ca_signature_algorithms: Vec<String>gateway_ports: Option<String>exit_on_forward_failure: Option<bool>permit_remote_open: Vec<String>hostbased_authentication: Option<bool>hostbased_accepted_algorithms: Vec<String>permit_local_command: Option<bool>local_command: Option<String>remote_command: Option<String>known_hosts_command: Option<String>fork_after_authentication: Option<bool>session_type: Option<String>stdin_null: Option<bool>no_host_authentication_for_localhost: Option<bool>hash_known_hosts: Option<bool>check_host_ip: Option<bool>visual_host_key: Option<bool>host_key_alias: Option<String>verify_host_key_dns: Option<String>update_host_keys: Option<String>number_of_password_prompts: Option<u32>enable_ssh_keysign: Option<bool>bind_interface: Option<String>ipqos: Option<String>rekey_limit: Option<String>forward_x11_timeout: Option<String>forward_x11_trusted: Option<bool>identities_only: Option<bool>add_keys_to_agent: Option<String>identity_agent: Option<String>pubkey_accepted_algorithms: Vec<String>required_rsa_size: Option<u32>fingerprint_hash: Option<String>Trait Implementations
Sourceimpl Clone for SshHostConfig
impl Clone for SshHostConfig
Sourcefn clone(&self) -> SshHostConfig
fn clone(&self) -> SshHostConfig
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SshHostConfig
impl Debug for SshHostConfig
Sourceimpl Default for SshHostConfig
impl Default for SshHostConfig
Sourcefn default() -> SshHostConfig
fn default() -> SshHostConfig
Returns the “default value” for a type. Read more
Sourceimpl Display for SshHostConfig
impl Display for SshHostConfig
Sourceimpl PartialEq for SshHostConfig
impl PartialEq for SshHostConfig
impl StructuralPartialEq for SshHostConfig